"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ClientAbstract_1 = require("./Client/ClientAbstract");
class ClientApi extends ClientAbstract_1.ClientRequestAbstract {
    /**
     * Charge cryptogram payment
     *
     * @param {CryptogramPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    chargeCryptogramPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/cards/charge", data);
        });
    }
    /**
     * Authorize cryptogram payment
     *
     * @param {CryptogramPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    authorizeCryptogramPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/cards/auth", data);
        });
    }
    /**
     * Charge token payment
     *
     * @param {TokenPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    chargeTokenPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/tokens/charge", data);
        });
    }
    /**
     * Authorize token payment
     *
     * @param {TokenPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    authorizeTokenPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/tokens/auth", data);
        });
    }
    /**
     * Confirm a 3DS payment
     *
     * @param {Confirm3DSRequest} data
     * @returns {Promise<Response<PaymentResponse>>}
     */
    confirm3DSPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/cards/post3ds", data);
        });
    }
    /**
     * Confirm an authorized payment
     *
     * @param {ConfirmPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    confirmPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/confirm", data);
        });
    }
    /**
     * Refund a payment
     *
     * @param {RefundPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    refundPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/refund", data);
        });
    }
    /**
     * Void a payment
     *
     * @param {VoidPaymentRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    voidPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/void", data);
        });
    }
    /**
     * Get a payment history
     *
     * @param {{TransactionId: number}} data
     * @returns {Promise<Response<PaymentGetResponse>>}
     */
    getPayment(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/get", data);
        });
    }
    /**
     * Find a payment by invoice id
     *
     * @param {{InvoiceId: string}} data
     * @returns {Promise<Response<PaymentSuccessResponse | PaymentFailedResponse>>}
     */
    findPaymentByInvoiceId(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/find", data);
        });
    }
    /**
     * @deprecated see getPaymentsList
     *
     * @param {{Date: string | Date, TimeZone: string}} data
     * @returns {Promise<Response<PaymentHistoryResponse>>}
     */
    getPaymentList(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/list", data);
        });
    }
    /**
     * Get a filtered payment list
     *
     * @param {{Date: string | Date, TimeZone: string}} data
     * @returns {Promise<Response<PaymentHistoryResponse>>}
     */
    getPaymentsList(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/list", data);
        });
    }
    /**
     * Get a filtered payment list
     *
     * @param {LinkPaymentRequest} data
     * @returns {Promise<Response<LinkPaymentModel>>}
     */
    createOrder(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/orders/create", data);
        });
    }
    createSubscription(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/subscriptions/create", data);
        });
    }
    updateSubscription(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/subscriptions/update", data);
        });
    }
    cancelSubscription(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/subscriptions/cancel", data);
        });
    }
    getSubscription(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/subscriptions/get", data);
        });
    }
    getSubscriptionsList(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/subscriptions/find", data);
        });
    }
    /**
     * Charge Cryptogram payout
     *
     * @param {CryptogramPayoutRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    chargeCryptogramPayout(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/cards/topup", data);
        });
    }
    /**
     * Charge token payout
     *
     * @param {TokenPayoutRequest} data
     * @returns {Promise<Response<BaseResponse>>}
     */
    chargeTokenPayout(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.call("/payments/token/topup ", data);
        });
    }
}
exports.ClientApi = ClientApi;
