"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ClientAbstract_1 = require("./Client/ClientAbstract");
const qs = require("qs");
const utils_1 = require("./utils");
const url_1 = require("url");
const assert_1 = require("assert");
class NotificationHandlers extends ClientAbstract_1.ClientAbstract {
    handleCheckRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handlePayRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handleConfirmRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handleFailRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handleRefundRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handleRecurrentRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handleReceiptRequest(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.handle(req, validator);
        });
    }
    handle(req, validator) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let request;
                if ("payload" in req) {
                    request = yield this.checkPayload(req);
                }
                else {
                    request = yield this.parseRequest(req);
                }
                if (validator) {
                    const code = yield validator(request);
                    return { request, response: { code } };
                }
                return { request, response: {} };
            }
            catch (error) {
                throw error;
            }
        });
    }
    checkPayload(req) {
        return __awaiter(this, void 0, void 0, function* () {
            let signature = "";
            if (req.headers && !req.signature) {
                assert_1.ok("content-hmac" in req.headers, "Request headers should contain Content-HMAC field.");
                signature = req.headers["content-hmac"];
            }
            if (req.signature) {
                signature = req.signature;
            }
            const payload = typeof req.payload === "string" ? req.payload : JSON.stringify(req.payload);
            assert_1.ok(signature, "Custom payload should provide signature or header key.");
            assert_1.ok(utils_1.checkSignedString(this.options.privateKey, signature, payload), "Invalid signature");
            return req.payload;
        });
    }
    parseRequest(req) {
        return __awaiter(this, void 0, void 0, function* () {
            assert_1.ok("content-hmac" in req.headers, "Request headers should contain Content-HMAC field.");
            const signature = req.headers["content-hmac"];
            const method = req.method || "";
            const request = {};
            assert_1.ok(!!method, "Request method should not be empty");
            if (method.toUpperCase() === "POST") {
                let chunksLength = 0;
                const chunks = [];
                const body = yield new Promise((resolve, reject) => {
                    req.on("data", (chunk) => {
                        chunks.push(chunk);
                        chunksLength += chunk.length;
                    });
                    req.on("end", () => resolve(Buffer
                        .concat(chunks, chunksLength)
                        .toString("utf-8")));
                    req.on("error", reject);
                });
                const headers = req.headers || {};
                assert_1.ok(utils_1.checkSignedString(this.options.privateKey, signature, body), "Invalid signature");
                if ("content-type" in headers && headers["content-type"].indexOf("json") !== -1) {
                    Object.assign(request, JSON.parse(body));
                }
                else {
                    Object.assign(request, qs.parse(body));
                }
            }
            else if (method.toUpperCase() === "GET") {
                assert_1.ok(utils_1.checkSignedString(this.options.privateKey, signature, url_1.parse(req.url || "").query), "Invalid signature");
                Object.assign(request, url_1.parse(req.url || "", true).query);
            }
            return request;
        });
    }
}
exports.NotificationHandlers = NotificationHandlers;
